@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAddressBook_VERSION = "4.1.60205"
+IAddressBook_VERSION = "4.1.61871"
 
 class IAddressBook(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -231,6 +231,20 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VCardInfoSerDer__()), response)
+    def updateWithItem (self, cardItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__VCardSerDer__()).encode(cardItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def count (self, arg0 ):
         postUri = "/_count";
         __data__ = None
@@ -345,6 +359,20 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
+    def createWithItem (self, cardItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__VCardSerDer__()).encode(cardItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def containerChangelog (self, arg0 ):
         postUri = "/_changelog";
         __data__ = None
