@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ICalendar_VERSION = "4.1.60205"
+ICalendar_VERSION = "4.1.61871"
 
 class ICalendar(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -178,6 +178,20 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
+    def updateWithItem (self, eventItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__VEventSeriesSerDer__()).encode(eventItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def count (self, arg0 ):
         postUri = "/_count";
         __data__ = None
@@ -306,6 +320,20 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
+    def createWithItem (self, eventItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__VEventSeriesSerDer__()).encode(eventItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def containerChangelog (self, arg0 ):
         postUri = "/_changelog";
         __data__ = None
