@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IComputerTelephonyIntegration_VERSION = "4.1.60205"
+IComputerTelephonyIntegration_VERSION = "4.1.61871"
 
 class IComputerTelephonyIntegration(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ,userUid ):
@@ -34,6 +34,14 @@ class IComputerTelephonyIntegration(BaseEndpoint):
         self.userUid_ = userUid
         self.base = self.base.replace('{userUid}',userUid)
 
+    def getUserEmails (self):
+        postUri = "/users";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IComputerTelephonyIntegration_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def forward (self, component , phoneNumber ):
         postUri = "/forward/{component}";
         __data__ = None
