@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IOrgUnits_VERSION = "4.1.60205"
+IOrgUnits_VERSION = "4.1.61871"
 
 class IOrgUnits(BaseEndpoint):
     def __init__(self, apiKey, url ,domain ):
@@ -32,6 +32,20 @@ class IOrgUnits(BaseEndpoint):
         self.domain_ = domain
         self.base = self.base.replace('{domain}',domain)
 
+    def updateWithItem (self, orgUnitItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.directory.api.OrgUnit import OrgUnit
+        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__OrgUnitSerDer__()).encode(orgUnitItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def getAdministratorRoles (self, uid , dirUid , groups ):
         postUri = "/{uid}/{dirUid}";
         __data__ = None
@@ -135,6 +149,20 @@ class IOrgUnits(BaseEndpoint):
         from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
         from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
         return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)
+    def createWithItem (self, orgUnitItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.directory.api.OrgUnit import OrgUnit
+        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__OrgUnitSerDer__()).encode(orgUnitItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def getPath (self, uid ):
         postUri = "/{uid}/path";
         __data__ = None
