@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IExternalUser_VERSION = "4.1.60205"
+IExternalUser_VERSION = "4.1.61871"
 
 class IExternalUser(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -45,6 +45,20 @@ class IExternalUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__ExternalUserSerDer__()), response)
+    def updateWithItem (self, externalUserItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.externaluser.api.ExternalUser import ExternalUser
+        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__ExternalUserSerDer__()).encode(externalUserItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def update (self, uid , externalUser ):
         postUri = "/{uid}";
         __data__ = None
@@ -80,6 +94,20 @@ class IExternalUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__ExternalUserSerDer__()), response)
+    def createWithItem (self, externalUserItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.externaluser.api.ExternalUser import ExternalUser
+        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__ExternalUserSerDer__()).encode(externalUserItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def create (self, uid , externalUser ):
         postUri = "/{uid}";
         __data__ = None
