@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailshare_VERSION = "4.1.60205"
+IMailshare_VERSION = "4.1.61871"
 
 class IMailshare(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -32,6 +32,20 @@ class IMailshare(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}',domainUid)
 
+    def updateWithItem (self, mailshareItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.mailshare.api.Mailshare import Mailshare
+        from netbluemind.mailshare.api.Mailshare import __MailshareSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__MailshareSerDer__()).encode(mailshareItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailshare_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def getPhoto (self, uid ):
         postUri = "/{uid}/photo";
         __data__ = None
@@ -96,6 +110,20 @@ class IMailshare(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__MailshareSerDer__()), response)
+    def createWithItem (self, mailshareItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.mailshare.api.Mailshare import Mailshare
+        from netbluemind.mailshare.api.Mailshare import __MailshareSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__MailshareSerDer__()).encode(mailshareItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailshare_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def setPhoto (self, uid , arg1 ):
         postUri = "/{uid}/photo";
         __data__ = None
