@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IExternalSystem_VERSION = "4.1.60205"
+IExternalSystem_VERSION = "4.1.61871"
 
 class IExternalSystem(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -39,6 +39,21 @@ class IExternalSystem(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalSystem_VERSION}, data = __encoded__);
         return self.handleResult__(serder.ByteArraySerDer, response)
+    def testConnection (self, systemIdentifier , account ):
+        postUri = "/{systemIdentifier}/_test_connection";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{systemIdentifier}",systemIdentifier);
+        from netbluemind.user.api.UserAccount import UserAccount
+        from netbluemind.user.api.UserAccount import __UserAccountSerDer__
+        __data__ = __UserAccountSerDer__().encode(account)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalSystem_VERSION}, data = __encoded__);
+        from netbluemind.system.api.ConnectionTestStatus import ConnectionTestStatus
+        from netbluemind.system.api.ConnectionTestStatus import __ConnectionTestStatusSerDer__
+        return self.handleResult__(__ConnectionTestStatusSerDer__(), response)
     def getExternalSystem (self, systemIdentifier ):
         postUri = "/{systemIdentifier}";
         __data__ = None
