@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IInstallation_VERSION = "4.1.60205"
+IInstallation_VERSION = "4.1.61871"
 
 class IInstallation(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -212,6 +212,14 @@ class IInstallation(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
+    def demoteLeader (self):
+        postUri = "/state/_demote";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def updateSubscription (self, licence ):
         postUri = "/subscription";
         __data__ = None
@@ -240,6 +248,20 @@ class IInstallation(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
+    def clone (self, sourceParams ):
+        postUri = "/_clone";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.system.api.CloneConfiguration import CloneConfiguration
+        from netbluemind.system.api.CloneConfiguration import __CloneConfigurationSerDer__
+        __data__ = __CloneConfigurationSerDer__().encode(sourceParams)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
     def getSubscriptionInformations (self):
         postUri = "/subscription";
         __data__ = None
@@ -278,3 +300,11 @@ class IInstallation(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
+    def promoteLeader (self):
+        postUri = "/state/_promote";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
