@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ITodoList_VERSION = "4.1.60205"
+ITodoList_VERSION = "4.1.61871"
 
 class ITodoList(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -212,6 +212,20 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
+    def updateWithItem (self, todoItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__VTodoSerDer__()).encode(todoItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def count (self, arg0 ):
         postUri = "/_count";
         __data__ = None
@@ -317,6 +331,20 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
+    def createWithItem (self, todoItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__VTodoSerDer__()).encode(todoItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def containerChangelog (self, arg0 ):
         postUri = "/_changelog";
         __data__ = None
