@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IUser_VERSION = "4.1.60205"
+IUser_VERSION = "4.1.61871"
 
 class IUser(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -235,6 +235,20 @@ class IUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
+    def updateWithItem (self, userItem ):
+        postUri = "/_updateWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__UserSerDer__()).encode(userItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def setExtId (self, uid , arg1 ):
         postUri = "/{uid}/_extId";
         __data__ = None
@@ -268,6 +282,20 @@ class IUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
+    def createWithItem (self, userItem ):
+        postUri = "/_createWithItem";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        __data__ = __ItemValueSerDer__(__UserSerDer__()).encode(userItem)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def setPhoto (self, uid , arg1 ):
         postUri = "/{uid}/photo";
         __data__ = None
